@@ -76,16 +76,16 @@ pub struct EconConnection {
     address: std::net::SocketAddr,
     stx: Sender<String>,
     rx: Receiver<EconMessage>,
-    //tx: Sender<EconMessage>,
+    tx: Sender<EconMessage>,
 }
 
 impl EconConnection {
     pub fn connect(address: std::net::SocketAddr, password: String) -> Self {
         let (tx, rx): (Sender<EconMessage>, Receiver<EconMessage>) = mpsc::channel();
-        //let sup_tx = tx.clone();
+        let sup_tx = tx.clone();
         let (stx, srx): (Sender<String>, Receiver<String>) = mpsc::channel();
         
-        let t = thread::spawn(move || {
+        thread::spawn(move || {
             let addr = address.clone();
             let mut password = password; password.push('\n');
             let mut stream = match TcpStream::connect(addr) {
@@ -163,14 +163,14 @@ impl EconConnection {
         EconConnection {
             address: address,
             stx,
-            //tx: sup_tx,
+            tx: sup_tx,
             rx,
         }
     }
 
     pub fn disconnect(&mut self) {
         let _ = self.stx.send(String::from(":disconnect!"));
-        //let _ = self.tx.send(EconMessage::from_string_with_current_time(&format!("[tw-econ]: Disconnected from '{}'", self.address)));
+        let _ = self.tx.send(EconMessage::from_string_with_current_time(&format!("[tw-econ]: Disconnected from '{}'", self.address)));
     }
 
     pub fn recv(&self) -> Result<EconMessage, mpsc::TryRecvError> {
